@@ -690,7 +690,8 @@ GlodaMessage.prototype = {
       if (folderMessage !== null) {
         // verify the message-id header matches what we expect...
         if (folderMessage.messageId != this._headerMessageID) {
-          LOG.info("Message with message key does not match expected " +
+          LOG.info("Message with message key " + this._messageKey +
+                   " in folder '" + folder.URI + "' does not match expected " +
                    "header! (" + this._headerMessageID + " expected, got " +
                    folderMessage.messageId + ")");
           folderMessage = null;
@@ -885,7 +886,7 @@ GlodaAttachment.prototype = {
       let url = neckoURL.value.spec;
       let hasParamAlready = url.match(/\?[a-z]+=[^\/]+$/);
       let sep = hasParamAlready ? "&" : "?";
-      return url+sep+"part="+this._part+"&filename="+this._name;
+      return url+sep+"part="+this._part+"&filename="+encodeURIComponent(this._name);
     }
   },
   get isExternal() { return this._isExternal; },
