@@ -67,19 +67,19 @@
 
 class OESettings {
 public:
-  static HKEY Find50Key( void);
-  static HKEY Find40Key( void);
-  static HKEY FindAccountsKey( void);
+  static HKEY Find50Key(void);
+  static HKEY Find40Key(void);
+  static HKEY FindAccountsKey(void);
 
-  static bool DoImport( nsIMsgAccount **ppAccount);
+  static bool DoImport(nsIMsgAccount **ppAccount);
 
-  static bool DoIMAPServer( nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount);
-  static bool DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount);
-  static bool DoNNTPServer( nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount);
+  static bool DoIMAPServer(nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount);
+  static bool DoPOP3Server(nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount);
+  static bool DoNNTPServer(nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount);
 
-  static void SetIdentities( nsIMsgAccountManager *pMgr, nsIMsgAccount *pAcc, HKEY hKey,
+  static void SetIdentities(nsIMsgAccountManager *pMgr, nsIMsgAccount *pAcc, HKEY hKey,
                              char *pIncomgUserName, PRInt32 authMethodIncoming, bool isNNTP);
-  static void SetSmtpServer( char *pSmtpServer, HKEY hKey, nsIMsgIdentity *id,
+  static void SetSmtpServer(char *pSmtpServer, HKEY hKey, nsIMsgIdentity *id,
                              char *pIncomgUserName, PRInt32 authMethodIncoming);
   static nsresult GetAccountName(HKEY hKey, char *defaultName, nsString &acctName);
   static bool IsKB933612Applied();
@@ -120,123 +120,124 @@ NS_IMETHODIMP nsOESettings::AutoLocate(PRUnichar **description, nsIFile **locati
   NS_PRECONDITION(description != nsnull, "null ptr");
   NS_PRECONDITION(_retval != nsnull, "null ptr");
   if (!description || !_retval)
-    return( NS_ERROR_NULL_POINTER);
+    return NS_ERROR_NULL_POINTER;
 
-  *description = nsOEStringBundle::GetStringByID( OEIMPORT_NAME);
-  *_retval = PR_FALSE;
+  *description = nsOEStringBundle::GetStringByID(OEIMPORT_NAME);
+  *_retval = false;
 
   if (location)
     *location = nsnull;
   HKEY  key;
   key = OESettings::Find50Key();
   if (key != nsnull) {
-    *_retval = PR_TRUE;
-    ::RegCloseKey( key);
+    *_retval = true;
+    ::RegCloseKey(key);
   }
   else {
     key = OESettings::Find40Key();
     if (key != nsnull) {
-      *_retval = PR_TRUE;
-      ::RegCloseKey( key);
+      *_retval = true;
+      ::RegCloseKey(key);
     }
   }
   if (*_retval) {
     key = OESettings::FindAccountsKey();
     if (key == nsnull) {
-      *_retval = PR_FALSE;
+      *_retval = false;
     }
     else {
-      ::RegCloseKey( key);
+      ::RegCloseKey(key);
     }
   }
 
-  return( NS_OK);
+  return NS_OK;
 }
 
 NS_IMETHODIMP nsOESettings::SetLocation(nsIFile *location)
 {
-  return( NS_OK);
+  return NS_OK;
 }
 
 NS_IMETHODIMP nsOESettings::Import(nsIMsgAccount **localMailAccount, bool *_retval)
 {
-  NS_PRECONDITION( _retval != nsnull, "null ptr");
+  NS_PRECONDITION(_retval != nsnull, "null ptr");
 
-  if (OESettings::DoImport( localMailAccount)) {
-    *_retval = PR_TRUE;
-    IMPORT_LOG0( "Settings import appears successful\n");
+  if (OESettings::DoImport(localMailAccount)) {
+    *_retval = true;
+    IMPORT_LOG0("Settings import appears successful\n");
   }
   else {
-    *_retval = PR_FALSE;
-    IMPORT_LOG0( "Settings import returned FALSE\n");
+    *_retval = false;
+    IMPORT_LOG0("Settings import returned FALSE\n");
   }
 
-  return( NS_OK);
+  return NS_OK;
 }
 
-HKEY OESettings::FindAccountsKey( void)
+HKEY OESettings::FindAccountsKey(void)
 {
   HKEY  sKey;
 
-  if (::RegOpenKeyEx( HKEY_CURRENT_USER, "Identities", 0, KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS) {
-    BYTE *  pBytes = nsOERegUtil::GetValueBytes( sKey, "Default User ID");
-    ::RegCloseKey( sKey);
+  if (::RegOpenKeyEx(HKEY_CURRENT_USER, "Identities", 0, KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS) {
+    BYTE *  pBytes = nsOERegUtil::GetValueBytes(sKey, "Default User ID");
+    ::RegCloseKey(sKey);
     if (pBytes) {
-      nsCString  key( "Identities\\");
+      nsCString  key("Identities\\");
       key += (const char *)pBytes;
-      nsOERegUtil::FreeValueBytes( pBytes);
+      nsOERegUtil::FreeValueBytes(pBytes);
       key += "\\Software\\Microsoft\\Internet Account Manager\\Accounts";
-      if (::RegOpenKeyEx( HKEY_CURRENT_USER, key.get(), 0, KEY_QUERY_VALUE | KEY_ENUMERATE_SUB_KEYS, &sKey) == ERROR_SUCCESS) {
-        return( sKey);
+      if (::RegOpenKeyEx(HKEY_CURRENT_USER, key.get(), 0, KEY_QUERY_VALUE | KEY_ENUMERATE_SUB_KEYS, &sKey) == ERROR_SUCCESS) {
+        return sKey;
       }
     }
   }
 
-  if (::RegOpenKeyEx( HKEY_CURRENT_USER, "Software\\Microsoft\\Internet Account Manager\\Accounts", 0, KEY_QUERY_VALUE | KEY_ENUMERATE_SUB_KEYS, &sKey) == ERROR_SUCCESS) {
-    return( sKey);
+  if (::RegOpenKeyEx(HKEY_CURRENT_USER, "Software\\Microsoft\\Internet Account Manager\\Accounts", 0, KEY_QUERY_VALUE | KEY_ENUMERATE_SUB_KEYS, &sKey) == ERROR_SUCCESS) {
+    return sKey;
   }
 
-  return( nsnull);
+  return nsnull;
 }
 
-HKEY OESettings::Find50Key( void)
+HKEY OESettings::Find50Key(void)
 {
   bool      success = false;
   HKEY    sKey;
 
-  if (::RegOpenKeyEx( HKEY_CURRENT_USER, "Identities", 0, KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS) {
-    BYTE *  pBytes = nsOERegUtil::GetValueBytes( sKey, "Default User ID");
-    ::RegCloseKey( sKey);
+  if (::RegOpenKeyEx(HKEY_CURRENT_USER, "Identities", 0, KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS) {
+    BYTE *  pBytes = nsOERegUtil::GetValueBytes(sKey, "Default User ID");
+    ::RegCloseKey(sKey);
     if (pBytes) {
-      nsCString  key( "Identities\\");
+      nsCString  key("Identities\\");
       key += (const char *)pBytes;
-      nsOERegUtil::FreeValueBytes( pBytes);
+      nsOERegUtil::FreeValueBytes(pBytes);
       key += "\\Software\\Microsoft\\Outlook Express\\5.0";
-      if (::RegOpenKeyEx( HKEY_CURRENT_USER, key.get(), 0, KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS) {
-        return( sKey);
+      if (::RegOpenKeyEx(HKEY_CURRENT_USER, key.get(), 0, KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS) {
+        return sKey;
       }
     }
   }
 
-  return( nsnull);
+  return nsnull;
 }
 
-HKEY OESettings::Find40Key( void)
+HKEY OESettings::Find40Key(void)
 {
   HKEY  sKey;
-  if (::RegOpenKeyEx( HKEY_CURRENT_USER, "Software\\Microsoft\\Outlook Express", 0, KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS) {
-    return( sKey);
-  }
+  if (::RegOpenKeyEx(HKEY_CURRENT_USER,
+                     "Software\\Microsoft\\Outlook Express", 0,
+                     KEY_QUERY_VALUE, &sKey) == ERROR_SUCCESS)
+    return sKey;
 
-  return( nsnull);
+  return nsnull;
 }
 
-bool OESettings::DoImport( nsIMsgAccount **ppAccount)
+bool OESettings::DoImport(nsIMsgAccount **ppAccount)
 {
   HKEY  hKey = FindAccountsKey();
   if (hKey == nsnull) {
-    IMPORT_LOG0( "*** Error finding Outlook Express registry account keys\n");
-    return( PR_FALSE);
+    IMPORT_LOG0("*** Error finding Outlook Express registry account keys\n");
+    return false;
   }
 
   nsresult  rv;
@@ -244,9 +245,9 @@ bool OESettings::DoImport( nsIMsgAccount **ppAccount)
   nsCOMPtr<nsIMsgAccountManager> accMgr =
            do_GetService(NS_MSGACCOUNTMANAGER_CONTRACTID, &rv);
     if (NS_FAILED(rv)) {
-    IMPORT_LOG0( "*** Failed to create a account manager!\n");
-    ::RegCloseKey( hKey);
-    return( PR_FALSE);
+    IMPORT_LOG0("*** Failed to create a account manager!\n");
+    ::RegCloseKey(hKey);
+    return false;
   }
 
   HKEY    subKey;
@@ -257,20 +258,20 @@ bool OESettings::DoImport( nsIMsgAccount **ppAccount)
   if (::RegOpenKeyEx(HKEY_CURRENT_USER, "Identities", 0,
                      KEY_QUERY_VALUE, &subKey) == ERROR_SUCCESS) {
     BYTE *  pBytes = nsOERegUtil::GetValueBytes(subKey, "Default User ID");
-    ::RegCloseKey( subKey);
+    ::RegCloseKey(subKey);
     if (pBytes) {
-      nsCString  key( "Identities\\");
+      nsCString  key("Identities\\");
       key += (const char *)pBytes;
-      nsOERegUtil::FreeValueBytes( pBytes);
+      nsOERegUtil::FreeValueBytes(pBytes);
       key += "\\Software\\Microsoft\\Internet Account Manager";
       if (::RegOpenKeyEx(HKEY_CURRENT_USER, key.get(), 0,
                          KEY_QUERY_VALUE , &subKey) == ERROR_SUCCESS) {
         BYTE * pBytes = nsOERegUtil::GetValueBytes(subKey,
                                                    "Default Mail Account");
-        ::RegCloseKey( subKey);
+        ::RegCloseKey(subKey);
         if (pBytes) {
           defMailName = (const char *)pBytes;
-          nsOERegUtil::FreeValueBytes( pBytes);
+          nsOERegUtil::FreeValueBytes(pBytes);
         }
       }
     }
@@ -283,10 +284,10 @@ bool OESettings::DoImport( nsIMsgAccount **ppAccount)
                        KEY_QUERY_VALUE, &subKey) == ERROR_SUCCESS) {
       BYTE *  pBytes = nsOERegUtil::GetValueBytes(subKey,
                                                   "Default Mail Account");
-      ::RegCloseKey( subKey);
+      ::RegCloseKey(subKey);
       if (pBytes) {
         defMailName = (const char *)pBytes;
-        nsOERegUtil::FreeValueBytes( pBytes);
+        nsOERegUtil::FreeValueBytes(pBytes);
       }
     }
   }
@@ -300,24 +301,24 @@ bool OESettings::DoImport( nsIMsgAccount **ppAccount)
   HKEY    subSubKey;
 
   subKey = Find50Key();
-  if (!subKey )
+  if (!subKey)
     subKey = Find40Key();
   // above key not critical
 
   checkNewMailTime = 30;
-  checkNewMail = PR_FALSE;
+  checkNewMail = false;
   if (subKey){
     if (::RegOpenKeyEx(subKey, "Mail", 0, KEY_QUERY_VALUE,
                        &subSubKey) == ERROR_SUCCESS) {
-      ::RegCloseKey( subKey);
-      BYTE *  pBytes = nsOERegUtil::GetValueBytes( subSubKey, "Poll For Mail");
-      ::RegCloseKey( subSubKey);
+      ::RegCloseKey(subKey);
+      BYTE *  pBytes = nsOERegUtil::GetValueBytes(subSubKey, "Poll For Mail");
+      ::RegCloseKey(subSubKey);
       if (pBytes) {
         if (*(PRInt32 *)pBytes != -1){
-          checkNewMail = PR_TRUE;
+          checkNewMail = true;
           checkNewMailTime = *(PRInt32 *)pBytes / 60000;
         }
-        nsOERegUtil::FreeValueBytes( pBytes);
+        nsOERegUtil::FreeValueBytes(pBytes);
       }
     }
   }
@@ -334,73 +335,73 @@ bool OESettings::DoImport( nsIMsgAccount **ppAccount)
 
   while (result == ERROR_SUCCESS) {
     numChars = 256;
-    result = ::RegEnumKeyEx( hKey, index, keyName, &numChars, NULL, NULL, NULL, NULL);
+    result = ::RegEnumKeyEx(hKey, index, keyName, &numChars, NULL, NULL, NULL, NULL);
     index++;
     if (result == ERROR_SUCCESS) {
-      if (::RegOpenKeyEx( hKey, keyName, 0, KEY_QUERY_VALUE, &subKey) == ERROR_SUCCESS) {
+      if (::RegOpenKeyEx(hKey, keyName, 0, KEY_QUERY_VALUE, &subKey) == ERROR_SUCCESS) {
         // Get the values for this account.
-        IMPORT_LOG1( "Opened Outlook Express account: %s\n", (char *)keyName);
+        IMPORT_LOG1("Opened Outlook Express account: %s\n", (char *)keyName);
 
         nsIMsgAccount  *anAccount = nsnull;
-        pBytes = nsOERegUtil::GetValueBytes( subKey, "IMAP Server");
+        pBytes = nsOERegUtil::GetValueBytes(subKey, "IMAP Server");
         if (pBytes) {
-          if (DoIMAPServer( accMgr, subKey, (char *)pBytes, &anAccount))
+          if (DoIMAPServer(accMgr, subKey, (char *)pBytes, &anAccount))
             accounts++;
-          nsOERegUtil::FreeValueBytes( pBytes);
+          nsOERegUtil::FreeValueBytes(pBytes);
         }
 
-        pBytes = nsOERegUtil::GetValueBytes( subKey, "NNTP Server");
+        pBytes = nsOERegUtil::GetValueBytes(subKey, "NNTP Server");
         if (pBytes) {
-          if (DoNNTPServer( accMgr, subKey, (char *)pBytes, &anAccount))
+          if (DoNNTPServer(accMgr, subKey, (char *)pBytes, &anAccount))
             accounts++;
-          nsOERegUtil::FreeValueBytes( pBytes);
+          nsOERegUtil::FreeValueBytes(pBytes);
         }
 
-        pBytes = nsOERegUtil::GetValueBytes( subKey, "POP3 Server");
+        pBytes = nsOERegUtil::GetValueBytes(subKey, "POP3 Server");
         if (pBytes) {
-            if (DoPOP3Server( accMgr, subKey, (char *)pBytes, &anAccount)) {
+            if (DoPOP3Server(accMgr, subKey, (char *)pBytes, &anAccount)) {
               accounts++;
           }
-          nsOERegUtil::FreeValueBytes( pBytes);
+          nsOERegUtil::FreeValueBytes(pBytes);
         }
 
         if (anAccount) {
           // Is this the default account?
           keyComp = keyName;
-          if (keyComp.Equals( defMailName)) {
-            accMgr->SetDefaultAccount( anAccount);
+          if (keyComp.Equals(defMailName)) {
+            accMgr->SetDefaultAccount(anAccount);
           }
-          NS_RELEASE( anAccount);
+          NS_RELEASE(anAccount);
         }
 
-        ::RegCloseKey( subKey);
+        ::RegCloseKey(subKey);
       }
     }
   }
-  ::RegCloseKey( hKey);
+  ::RegCloseKey(hKey);
 
   // Now save the new acct info to pref file.
   rv = accMgr->SaveAccountInfo();
   NS_ASSERTION(NS_SUCCEEDED(rv), "Can't save account info to pref file");
 
-  return( accounts != 0);
+  return accounts != 0;
 }
 
 nsresult OESettings::GetAccountName(HKEY hKey, char *defaultName, nsString &acctName)
 {
-  BYTE *pAccName = nsOERegUtil::GetValueBytes( hKey, "Account Name");
+  BYTE *pAccName = nsOERegUtil::GetValueBytes(hKey, "Account Name");
   nsresult rv = NS_OK;
   if (pAccName) {
     rv = nsMsgI18NConvertToUnicode(nsMsgI18NFileSystemCharset(),
                                    nsDependentCString((const char *)pAccName), acctName);
-    nsOERegUtil::FreeValueBytes( pAccName);
+    nsOERegUtil::FreeValueBytes(pAccName);
   }
   else
     acctName.AssignASCII(defaultName);
   return rv;
 }
 
-bool OESettings::DoIMAPServer( nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount)
+bool OESettings::DoIMAPServer(nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount)
 {
   PRInt32 authMethod;
   if (ppAccount)
@@ -409,7 +410,7 @@ bool OESettings::DoIMAPServer( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
   char * pUserName;
   pUserName = (char *)nsOERegUtil::GetValueBytes(hKey, "IMAP User Name");
   if (!pUserName)
-    return( PR_FALSE);
+    return false;
 
   bool result = false;
 
@@ -419,13 +420,13 @@ bool OESettings::DoIMAPServer( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
                                  nsDependentCString(pServerName),
                                  NS_LITERAL_CSTRING("imap"),
                                  getter_AddRefs(in));
-  if (NS_FAILED( rv) || (in == nsnull)) {
+  if (NS_FAILED(rv) || (in == nsnull)) {
     // Create the incoming server and an account for it?
     rv = pMgr->CreateIncomingServer(nsDependentCString(pUserName),
                                     nsDependentCString(pServerName),
                                     NS_LITERAL_CSTRING("imap"),
                                     getter_AddRefs(in));
-    if (NS_SUCCEEDED( rv) && in) {
+    if (NS_SUCCEEDED(rv) && in) {
       BYTE * pRootFolder = nsOERegUtil::GetValueBytes(hKey, "IMAP Root Folder");
       if (pRootFolder)
       {
@@ -474,15 +475,15 @@ bool OESettings::DoIMAPServer( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
 
       // We have a server, create an account.
       nsCOMPtr<nsIMsgAccount> account;
-      rv = pMgr->CreateAccount(getter_AddRefs( account));
-      if (NS_SUCCEEDED( rv) && account) {
+      rv = pMgr->CreateAccount(getter_AddRefs(account));
+      if (NS_SUCCEEDED(rv) && account) {
         rv = account->SetIncomingServer(in);
 
         IMPORT_LOG0("Created an account and set the IMAP server as the incoming server\n");
 
         // Fiddle with the identities
-        SetIdentities(pMgr, account, hKey, pUserName, authMethod, PR_FALSE);
-        result = PR_TRUE;
+        SetIdentities(pMgr, account, hKey, pUserName, authMethod, false);
+        result = true;
         if (ppAccount)
           account->QueryInterface(NS_GET_IID(nsIMsgAccount), (void **)ppAccount);
       }
@@ -492,34 +493,34 @@ bool OESettings::DoIMAPServer( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
     // for an existing server we create another identity,
     //  TB lists under 'manage identities'
     nsCOMPtr<nsIMsgAccount> account;
-    rv = pMgr->FindAccountForServer(in, getter_AddRefs( account));
-    if (NS_SUCCEEDED( rv) && account) {
+    rv = pMgr->FindAccountForServer(in, getter_AddRefs(account));
+    if (NS_SUCCEEDED(rv) && account) {
       IMPORT_LOG0("Created an identity and added to existing IMAP incoming server\n");
       // Fiddle with the identities
       in->GetAuthMethod(&authMethod);
-      SetIdentities(pMgr, account, hKey, pUserName, authMethod, PR_FALSE);
-      result = PR_TRUE;
+      SetIdentities(pMgr, account, hKey, pUserName, authMethod, false);
+      result = true;
       if (ppAccount)
         account->QueryInterface(NS_GET_IID(nsIMsgAccount),
                                  (void **)ppAccount);
     }
   }
   else
-    result = PR_TRUE;
+    result = true;
   nsOERegUtil::FreeValueBytes((BYTE *) pUserName);
-  return( result);
+  return result;
 }
 
-bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount)
+bool OESettings::DoPOP3Server(nsIMsgAccountManager *pMgr, HKEY hKey, char *pServerName, nsIMsgAccount **ppAccount)
 {
   PRInt32 authMethod;    // Secure Password Authentication
   if (ppAccount)
     *ppAccount = nsnull;
 
   char * pUserName;
-  pUserName = (char *)nsOERegUtil::GetValueBytes( hKey, "POP3 User Name");
+  pUserName = (char *)nsOERegUtil::GetValueBytes(hKey, "POP3 User Name");
   if (!pUserName)
-    return( PR_FALSE);
+    return false;
 
   bool result = false;
 
@@ -528,15 +529,15 @@ bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
   nsresult rv = pMgr->FindServer(nsDependentCString(pUserName),
                                  nsDependentCString(pServerName),
                                  NS_LITERAL_CSTRING("pop3"),
-                                 getter_AddRefs( in));
-  if (NS_FAILED( rv) || (in == nsnull)) {
+                                 getter_AddRefs(in));
+  if (NS_FAILED(rv) || (in == nsnull)) {
     // Create the incoming server and an account for it?
     rv = pMgr->CreateIncomingServer(nsDependentCString(pUserName),
                                     nsDependentCString(pServerName),
                                     NS_LITERAL_CSTRING("pop3"),
-                                    getter_AddRefs( in));
-    if (NS_SUCCEEDED( rv) && in) {
-      BYTE * pSecureConnection = nsOERegUtil::GetValueBytes( hKey, "POP3 Secure Connection");
+                                    getter_AddRefs(in));
+    if (NS_SUCCEEDED(rv) && in) {
+      BYTE * pSecureConnection = nsOERegUtil::GetValueBytes(hKey, "POP3 Secure Connection");
       if (pSecureConnection)
       {
         if (*pSecureConnection)
@@ -544,14 +545,14 @@ bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
         nsOERegUtil::FreeValueBytes(pSecureConnection);
       }
 
-      BYTE * pPort = nsOERegUtil::GetValueBytes( hKey, "POP3 Port");
+      BYTE * pPort = nsOERegUtil::GetValueBytes(hKey, "POP3 Port");
       if (pPort)
       {
         in->SetPort(*(PRInt32 *) pPort);
         nsOERegUtil::FreeValueBytes(pPort);
       }
 
-      BYTE * pBytesTemp = nsOERegUtil::GetValueBytes( hKey, "POP3 Use Sicily");
+      BYTE * pBytesTemp = nsOERegUtil::GetValueBytes(hKey, "POP3 Use Sicily");
       if (pBytesTemp)
       {
         bool secAuth = *(bool *)pBytesTemp;
@@ -578,7 +579,7 @@ bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
 
           if (NS_FAILED(pMgr->CreateLocalMailAccount())) {
             IMPORT_LOG0("*** Failed to create Local Folders!\n");
-            return PR_FALSE;
+            return false;
           }
 
           pMgr->GetLocalFoldersServer(getter_AddRefs(localFoldersServer));
@@ -603,7 +604,7 @@ bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
           nsOERegUtil::FreeValueBytes(pBytesTemp);
         }
         else
-          pop3Server->SetDeferGetNewMail(PR_FALSE);
+          pop3Server->SetDeferGetNewMail(false);
         pBytesTemp = nsOERegUtil::GetValueBytes(hKey, "Leave Mail On Server");
         if (pBytesTemp)
         {
@@ -625,7 +626,7 @@ bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
         pBytesTemp = nsOERegUtil::GetValueBytes(hKey, "Expire Days");
         if (pBytesTemp)
         {
-          pop3Server->SetNumDaysToLeaveOnServer(*(PRInt32*)pBytesTemp );
+          pop3Server->SetNumDaysToLeaveOnServer(*(PRInt32*)pBytesTemp);
           nsOERegUtil::FreeValueBytes(pBytesTemp);
         }
       }
@@ -633,18 +634,18 @@ bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
                    pServerName, pUserName);
       nsString prettyName;
       if (NS_SUCCEEDED(GetAccountName(hKey, pServerName, prettyName)))
-        rv = in->SetPrettyName( prettyName);
+        rv = in->SetPrettyName(prettyName);
 
       // We have a server, create an account.
       nsCOMPtr<nsIMsgAccount>  account;
-      rv = pMgr->CreateAccount(getter_AddRefs( account));
-      if (NS_SUCCEEDED( rv) && account) {
+      rv = pMgr->CreateAccount(getter_AddRefs(account));
+      if (NS_SUCCEEDED(rv) && account) {
         rv = account->SetIncomingServer(in);
         IMPORT_LOG0("Created a new account and set the incoming server to the POP3 server.\n");
 
         // Fiddle with the identities
-        SetIdentities(pMgr, account, hKey, pUserName, authMethod, PR_FALSE);
-        result = PR_TRUE;
+        SetIdentities(pMgr, account, hKey, pUserName, authMethod, false);
+        result = true;
         if (ppAccount)
           account->QueryInterface(NS_GET_IID(nsIMsgAccount),
                                    (void **)ppAccount);
@@ -657,24 +658,24 @@ bool OESettings::DoPOP3Server( nsIMsgAccountManager *pMgr, HKEY hKey, char *pSer
     // for an existing server we create another identity,
     // TB listed under 'manage identities'
     nsCOMPtr<nsIMsgAccount>  account;
-    rv = pMgr->FindAccountForServer(in, getter_AddRefs( account));
+    rv = pMgr->FindAccountForServer(in, getter_AddRefs(account));
     if (NS_SUCCEEDED(rv) && account) {
       IMPORT_LOG0("Created identity and added to existing POP3 incoming server.\n");
       // Fiddle with the identities
       in->GetAuthMethod(&authMethod);
-      SetIdentities(pMgr, account, hKey, pUserName, authMethod, PR_FALSE);
-      result = PR_TRUE;
+      SetIdentities(pMgr, account, hKey, pUserName, authMethod, false);
+      result = true;
       if (ppAccount)
         account->QueryInterface(NS_GET_IID(nsIMsgAccount), (void **)ppAccount);
     }
   }
   else
-    result = PR_TRUE;
+    result = true;
   nsOERegUtil::FreeValueBytes((BYTE *) pUserName);
   return result;
 }
 
-bool OESettings::DoNNTPServer( nsIMsgAccountManager *pMgr, HKEY hKey,
+bool OESettings::DoNNTPServer(nsIMsgAccountManager *pMgr, HKEY hKey,
                                 char *pServerName, nsIMsgAccount **ppAccount)
 {
   if (ppAccount)
@@ -693,13 +694,13 @@ bool OESettings::DoNNTPServer( nsIMsgAccountManager *pMgr, HKEY hKey,
                                  nsDependentCString(pServerName),
                                  NS_LITERAL_CSTRING("nntp"),
                                  getter_AddRefs(in));
-  if (NS_FAILED( rv) || (in == nsnull)) {
+  if (NS_FAILED(rv) || (in == nsnull)) {
     // Create the incoming server and an account for it?
     rv = pMgr->CreateIncomingServer(EmptyCString(),
                                     nsDependentCString(pServerName),
                                     NS_LITERAL_CSTRING("nntp"),
                                     getter_AddRefs(in));
-    if (NS_SUCCEEDED( rv) && in) {
+    if (NS_SUCCEEDED(rv) && in) {
       BYTE * pBytesTemp = nsOERegUtil::GetValueBytes(hKey, "NNTP Port");
       if (pBytesTemp && *(PRInt32 *)pBytesTemp != 119)
         in->SetPort(*(PRInt32 *) pBytesTemp);
@@ -708,7 +709,7 @@ bool OESettings::DoNNTPServer( nsIMsgAccountManager *pMgr, HKEY hKey,
       // do nntpincomingserver stuff
       nsCOMPtr<nsINntpIncomingServer> nntpServer = do_QueryInterface(in);
       if (nntpServer && pUserName && *pUserName) {
-        nntpServer->SetPushAuth(PR_TRUE);
+        nntpServer->SetPushAuth(true);
         in->SetUsername(nsDependentCString(pUserName));
       }
 
@@ -721,15 +722,15 @@ bool OESettings::DoNNTPServer( nsIMsgAccountManager *pMgr, HKEY hKey,
 
       // We have a server, create an account.
       nsCOMPtr<nsIMsgAccount> account;
-      rv = pMgr->CreateAccount(getter_AddRefs( account));
+      rv = pMgr->CreateAccount(getter_AddRefs(account));
       if (NS_SUCCEEDED(rv) && account) {
         rv = account->SetIncomingServer(in);
 
         IMPORT_LOG0("Created an account and set the NNTP server as the incoming server\n");
 
         // Fiddle with the identities
-        SetIdentities(pMgr, account, hKey, pUserName, 0, PR_TRUE);
-        result = PR_TRUE;
+        SetIdentities(pMgr, account, hKey, pUserName, 0, true);
+        result = true;
         if (ppAccount)
           account->QueryInterface(NS_GET_IID(nsIMsgAccount), (void **)ppAccount);
       }
@@ -738,26 +739,26 @@ bool OESettings::DoNNTPServer( nsIMsgAccountManager *pMgr, HKEY hKey,
   else if (NS_SUCCEEDED(rv) && in) {
     // for the existing server...
     nsCOMPtr<nsIMsgAccount> account;
-    rv = pMgr->FindAccountForServer(in, getter_AddRefs( account));
-    if (NS_SUCCEEDED( rv) && account) {
+    rv = pMgr->FindAccountForServer(in, getter_AddRefs(account));
+    if (NS_SUCCEEDED(rv) && account) {
       IMPORT_LOG0("Using existing account and set the NNTP server as the incoming server\n");
       // Fiddle with the identities
-      SetIdentities(pMgr, account, hKey, pUserName, 0, PR_TRUE);
-      result = PR_TRUE;
+      SetIdentities(pMgr, account, hKey, pUserName, 0, true);
+      result = true;
       if (ppAccount)
         account->QueryInterface(NS_GET_IID(nsIMsgAccount),
                                  (void **)ppAccount);
     }
   }
   else
-    result = PR_TRUE;
+    result = true;
   nsOERegUtil::FreeValueBytes((BYTE *) pUserName);
   return result;
 }
 
 void OESettings::SetIdentities(nsIMsgAccountManager *pMgr, nsIMsgAccount *pAcc,
                                HKEY hKey, char *pIncomgUserName,
-                               PRInt32 authMethodIncoming, bool isNNTP )
+                               PRInt32 authMethodIncoming, bool isNNTP)
 {
   // Get the relevant information for an identity
   char *pSmtpServer = (char *)nsOERegUtil::GetValueBytes(hKey, "SMTP Server");
@@ -844,8 +845,8 @@ void OESettings::SetSmtpServer(char *pSmtpServer, HKEY hKey,
     // don't try to make another server
     // regardless if username doesn't match
     rv = smtpService->FindServer(userName.get(), pSmtpServer,
-                                 getter_AddRefs( foundServer));
-    if (NS_SUCCEEDED( rv) && foundServer) {
+                                 getter_AddRefs(foundServer));
+    if (NS_SUCCEEDED(rv) && foundServer) {
       // set our account keyed to this smptserver key
       foundServer->GetKey(getter_Copies(smtpServerKey));
       id->SetSmtpServerKey(smtpServerKey);
@@ -855,8 +856,8 @@ void OESettings::SetSmtpServer(char *pSmtpServer, HKEY hKey,
     else {
       nsCOMPtr<nsISmtpServer> smtpServer;
       PRInt32 port;
-      rv = smtpService->CreateSmtpServer(getter_AddRefs( smtpServer));
-      if (NS_SUCCEEDED( rv) && smtpServer) {
+      rv = smtpService->CreateSmtpServer(getter_AddRefs(smtpServer));
+      if (NS_SUCCEEDED(rv) && smtpServer) {
         pBytes = nsOERegUtil::GetValueBytes(hKey, "SMTP Port");
         if (pBytes)
         {
