@@ -66,6 +66,7 @@
 #include "nsNetUtil.h"
 #include "nsISimpleEnumerator.h"
 #include "nsMsgUtils.h"
+#include "mozilla/Services.h"
 
 #define INVALID_VERSION         0
 #define VALID_VERSION           2
@@ -92,16 +93,24 @@
 // operating system.
 #define HOSTINFO_FILE_BUFFER_SIZE 1024
 
-#ifndef MOZILLA_INTERNAL_API
-/// SortIgnoreCase() is not supported. Define our own private version.
-static int
-CompareCStringIgnoreCase(const nsCString* aString1, const nsCString* aString2, void*)
+#include "nsMsgUtils.h"
+
+/**
+ * A comparator class to do cases insensitive comparisons for nsTArray.Sort()
+ */
+class nsCStringLowerCaseComparator
 {
-  return Compare(*aString1, *aString2, CaseInsensitiveCompare);
-}
-#define SortIgnoreCase() \
-        Sort(CompareCStringIgnoreCase, nsnull)
-#endif
+public:
+  bool Equals(const nsCString &a, const nsCString &b) const
+  {
+    return a.Equals(b, nsCaseInsensitiveCStringComparator());
+  }
+
+  bool LessThan(const nsCString &a, const nsCString &b) const
+  {
+    return Compare(a, b, nsCaseInsensitiveCStringComparator());
+  }
+};
 
 static NS_DEFINE_CID(kSubscribableServerCID, NS_SUBSCRIBABLESERVER_CID);
 
@@ -117,17 +126,16 @@ NS_INTERFACE_MAP_END_INHERITING(nsMsgIncomingServer)
 
 nsNntpIncomingServer::nsNntpIncomingServer()
 {
-  mNewsrcHasChanged = PR_FALSE;
+  mNewsrcHasChanged = false;
 
-  mHostInfoLoaded = PR_FALSE;
-  mHostInfoHasChanged = PR_FALSE;
+  mHostInfoLoaded = false;
+  mHostInfoHasChanged = false;
   mVersion = INVALID_VERSION;
 
   mLastGroupDate = 0;
   mUniqueId = 0;
-  mHasSeenBeginGroups = PR_FALSE;
-  mPostingAllowed = PR_FALSE;
-  m_userAuthenticated = PR_FALSE;
+  mHasSeenBeginGroups = false;
+  mPostingAllowed = false;
   mLastUpdatedTime = 0;
 
   // these atoms are used for subscribe search
@@ -135,7 +143,7 @@ nsNntpIncomingServer::nsNntpIncomingServer()
   mNntpAtom = MsgGetAtom("nntp");
 
   // we have server wide and per group filters
-  m_canHaveFilters = PR_TRUE;
+  m_canHaveFilters = true;
 
   SetupNewsrcSaveTimer();
 }
@@ -218,7 +226,7 @@ nsNntpIncomingServer::SetNewsrcFilePath(nsILocalFile *aFile)
 {
     NS_ENSURE_ARG_POINTER(aFile);
 
-    PRBool exists;
+    bool exists;
     nsresult rv = aFile->Exists(&exists);
     if (!exists)
     {
@@ -248,7 +256,7 @@ nsNntpIncomingServer::GetNewsrcRootPath(nsILocalFile **aNewsrcRootPath)
     NS_ENSURE_ARG_POINTER(aNewsrcRootPath);
     *aNewsrcRootPath = nsnull;
 
-    PRBool havePref;
+    bool havePref;
     nsresult rv = NS_GetPersistentFile(PREF_MAIL_NEWSRC_ROOT_REL,
                               PREF_MAIL_NEWSRC_ROOT,
                               NS_APP_NEWS_50_DIR,
@@ -257,7 +265,7 @@ nsNntpIncomingServer::GetNewsrcRootPath(nsILocalFile **aNewsrcRootPath)
 
     NS_ENSURE_SUCCESS(rv, rv);
 
-    PRBool exists;
+    bool exists;
     rv = (*aNewsrcRootPath)->Exists(&exists);
     if (NS_SUCCEEDED(rv) && !exists)
         rv = (*aNewsrcRootPath)->Create(nsIFile::DIRECTORY_TYPE, 0775);
@@ -323,7 +331,7 @@ nsNntpIncomingServer::WriteNewsrcFile()
 {
     nsresult rv;
 
-    PRBool newsrcHasChanged;
+    bool newsrcHasChanged;
     rv = GetNewsrcHasChanged(&newsrcHasChanged);
     if (NS_FAILED(rv)) return rv;
 
@@ -386,7 +394,7 @@ nsNntpIncomingServer::WriteNewsrcFile()
         rv = rootFolder->GetSubFolders(getter_AddRefs(subFolders));
         if (NS_FAILED(rv)) return rv;
 
-        PRBool moreFolders;
+        bool moreFolders;
 
         while (NS_SUCCEEDED(subFolders->HasMoreElements(&moreFolders)) &&
                moreFolders) {
@@ -407,7 +415,7 @@ nsNntpIncomingServer::WriteNewsrcFile()
 
         newsrcStream->Close();
 
-        rv = SetNewsrcHasChanged(PR_FALSE);
+        rv = SetNewsrcHasChanged(false);
         if (NS_FAILED(rv)) return rv;
     }
 #ifdef DEBUG_NEWS
@@ -420,14 +428,14 @@ nsNntpIncomingServer::WriteNewsrcFile()
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::SetNewsrcHasChanged(PRBool aNewsrcHasChanged)
+nsNntpIncomingServer::SetNewsrcHasChanged(bool aNewsrcHasChanged)
 {
     mNewsrcHasChanged = aNewsrcHasChanged;
     return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetNewsrcHasChanged(PRBool *aNewsrcHasChanged)
+nsNntpIncomingServer::GetNewsrcHasChanged(bool *aNewsrcHasChanged)
 {
     if (!aNewsrcHasChanged) return NS_ERROR_NULL_POINTER;
 
@@ -435,8 +443,6 @@ nsNntpIncomingServer::GetNewsrcHasChanged(PRBool *aNewsrcHasChanged)
     return NS_OK;
 }
 
-NS_IMPL_GETSET(nsNntpIncomingServer, UserAuthenticated, PRBool, m_userAuthenticated)
-
 NS_IMETHODIMP
 nsNntpIncomingServer::CloseCachedConnections()
 {
@@ -474,10 +480,10 @@ nsNntpIncomingServer::CloseCachedConnections()
 NS_IMPL_SERVERPREF_INT(nsNntpIncomingServer, MaximumConnectionsNumber,
                        "max_cached_connections")
 
-PRBool
+bool
 nsNntpIncomingServer::ConnectionTimeOut(nsINNTPProtocol* aConnection)
 {
-    PRBool retVal = PR_FALSE;
+    bool retVal = false;
     if (!aConnection) return retVal;
     nsresult rv;
 
@@ -498,7 +504,7 @@ nsNntpIncomingServer::ConnectionTimeOut(nsINNTPProtocol* aConnection)
 #endif
       aConnection->CloseConnection();
       mConnectionCache.RemoveObject(aConnection);
-      retVal = PR_TRUE;
+      retVal = true;
     }
     return retVal;
 }
@@ -553,7 +559,7 @@ nsNntpIncomingServer::GetNntpConnection(nsIURI * aUri, nsIMsgWindow *aMsgWindow,
     connection = mConnectionCache[i];
     if (connection)
     {
-      PRBool isBusy;
+      bool isBusy;
       connection->GetIsBusy(&isBusy);
       if (!isBusy)
         break;
@@ -571,7 +577,7 @@ nsNntpIncomingServer::GetNntpConnection(nsIURI * aUri, nsIMsgWindow *aMsgWindow,
   if (connection)
   {
     NS_IF_ADDREF(*aNntpConnection = connection);
-    connection->SetIsCachedConnection(PR_TRUE);
+    connection->SetIsCachedConnection(true);
   }
   else if (cnt < maxConnections)
   {
@@ -672,7 +678,7 @@ nsNntpIncomingServer::PerformExpand(nsIMsgWindow *aMsgWindow)
 {
   // Get news.update_unread_on_expand pref
   nsresult rv;
-  PRBool updateUnreadOnExpand = PR_TRUE;
+  bool updateUnreadOnExpand = true;
   nsCOMPtr<nsIPrefBranch> prefBranch = do_GetService(NS_PREFSERVICE_CONTRACTID, &rv);
   if (NS_SUCCEEDED(rv))
     prefBranch->GetBoolPref("news.update_unread_on_expand", &updateUnreadOnExpand);
@@ -694,7 +700,7 @@ nsNntpIncomingServer::DownloadMail(nsIMsgWindow *aMsgWindow)
   rv = rootFolder->GetSubFolders(getter_AddRefs(groups));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  PRBool hasNext;
+  bool hasNext;
   while (NS_SUCCEEDED(rv = groups->HasMoreElements(&hasNext)) && hasNext)
   {
     nsCOMPtr<nsISupports> nextGroup;
@@ -730,10 +736,10 @@ nsNntpIncomingServer::PerformBiff(nsIMsgWindow *aMsgWindow)
   return PerformExpand(aMsgWindow);
 }
 
-NS_IMETHODIMP nsNntpIncomingServer::GetServerRequiresPasswordForBiff(PRBool *aServerRequiresPasswordForBiff)
+NS_IMETHODIMP nsNntpIncomingServer::GetServerRequiresPasswordForBiff(bool *aServerRequiresPasswordForBiff)
 {
   NS_ENSURE_ARG_POINTER(aServerRequiresPasswordForBiff);
-  *aServerRequiresPasswordForBiff = PR_FALSE;  // for news, biff is getting the unread counts
+  *aServerRequiresPasswordForBiff = false;  // for news, biff is getting the unread counts
   return NS_OK;
 }
 
@@ -756,29 +762,25 @@ nsNntpIncomingServer::OnStopRunningUrl(nsIURI *url, nsresult exitCode)
   return NS_OK;
 }
 
-
-PRBool
-checkIfSubscribedFunction(nsCString &aElement, void *aData)
-{
-    if (aElement.Equals(*static_cast<nsACString *>(aData))) {
-        return PR_FALSE;
-    }
-    else {
-        return PR_TRUE;
-    }
-}
-
-
 NS_IMETHODIMP
 nsNntpIncomingServer::ContainsNewsgroup(const nsACString &name,
-                                        PRBool *containsGroup)
+                                        bool *containsGroup)
 {
     if (name.IsEmpty()) return NS_ERROR_FAILURE;
+    if (mSubscribedNewsgroups.Length() == 0)
+    {
+      // If this is empty, we may need to discover folders
+      nsCOMPtr<nsIMsgFolder> rootFolder;
+      GetRootFolder(getter_AddRefs(rootFolder));
+      if (rootFolder)
+      {
+        nsCOMPtr<nsISimpleEnumerator> subfolders;
+        rootFolder->GetSubFolders(getter_AddRefs(subfolders));
+      }
+    }
     nsCAutoString unescapedName;
     MsgUnescapeString(name, 0, unescapedName);
-    *containsGroup = !(mSubscribedNewsgroups.EnumerateForwards(
-                       nsCStringArrayEnumFunc(checkIfSubscribedFunction),
-                       (void *) &unescapedName));
+    *containsGroup = mSubscribedNewsgroups.Contains(name);
     return NS_OK;
 }
 
@@ -799,7 +801,7 @@ nsNntpIncomingServer::SubscribeToNewsgroup(const nsACString &aName)
     return NS_OK;
 }
 
-PRBool
+bool
 writeGroupToHostInfoFile(nsCString &aElement, void *aData)
 {
     nsIOutputStream *stream;
@@ -807,12 +809,9 @@ writeGroupToHostInfoFile(nsCString &aElement, void *aData)
     NS_ASSERTION(stream, "no stream");
     if (!stream) {
         // stop, something is bad.
-        return PR_FALSE;
+        return false;
     }
-    PRUint32 bytesWritten;
-    stream->Write(aElement.get(), aElement.Length(), &bytesWritten);
-    stream->Write(MSG_LINEBREAK, MSG_LINEBREAK_LEN, &bytesWritten);
-    return PR_TRUE;
+    return true;
 }
 
 void nsNntpIncomingServer::WriteLine(nsIOutputStream *stream, nsCString &str)
@@ -868,11 +867,17 @@ nsNntpIncomingServer::WriteHostInfoFile()
   WriteLine(hostInfoStream, header);
 
   // XXX todo, sort groups first?
-
-  mGroupsOnServer.EnumerateForwards((nsCStringArrayEnumFunc)writeGroupToHostInfoFile, (void *)hostInfoStream);
+  PRUint32 length = mGroupsOnServer.Length();
+  for (PRUint32 i = 0; i < length; ++i)
+  {
+    PRUint32 bytesWritten;
+    hostInfoStream->Write(mGroupsOnServer[i].get(), mGroupsOnServer[i].Length(),
+                          &bytesWritten);
+    hostInfoStream->Write(MSG_LINEBREAK, MSG_LINEBREAK_LEN, &bytesWritten);
+  }
 
   hostInfoStream->Close();
-  mHostInfoHasChanged = PR_FALSE;
+  mHostInfoHasChanged = false;
   return NS_OK;
 }
 
@@ -881,7 +886,7 @@ nsNntpIncomingServer::LoadHostInfoFile()
 {
   nsresult rv;
   // we haven't loaded it yet
-  mHostInfoLoaded = PR_FALSE;
+  mHostInfoLoaded = false;
 
   rv = GetLocalPath(getter_AddRefs(mHostInfoFile));
   if (NS_FAILED(rv)) return rv;
@@ -890,7 +895,7 @@ nsNntpIncomingServer::LoadHostInfoFile()
   rv = mHostInfoFile->AppendNative(NS_LITERAL_CSTRING(HOSTINFO_FILE_NAME));
   if (NS_FAILED(rv)) return rv;
 
-  PRBool exists;
+  bool exists;
   rv = mHostInfoFile->Exists(&exists);
   if (NS_FAILED(rv)) return rv;
 
@@ -904,7 +909,7 @@ nsNntpIncomingServer::LoadHostInfoFile()
   nsCOMPtr<nsILineInputStream> lineInputStream(do_QueryInterface(fileStream, &rv));
   NS_ENSURE_SUCCESS(rv, nsnull);
 
-  PRBool more = PR_TRUE;
+  bool more = true;
   nsCString line;
 
   while (more && NS_SUCCEEDED(rv))
@@ -914,14 +919,14 @@ nsNntpIncomingServer::LoadHostInfoFile()
       continue;
     HandleLine(line.get(), line.Length());
   }
-  mHasSeenBeginGroups = PR_FALSE;
+  mHasSeenBeginGroups = false;
   fileStream->Close();
 
   return UpdateSubscribed();
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::StartPopulatingWithUri(nsIMsgWindow *aMsgWindow, PRBool aForceToServer, const char *uri)
+nsNntpIncomingServer::StartPopulatingWithUri(nsIMsgWindow *aMsgWindow, bool aForceToServer, const char *uri)
 {
   nsresult rv = NS_OK;
 
@@ -950,7 +955,7 @@ nsNntpIncomingServer::SubscribeCleanup()
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::StartPopulating(nsIMsgWindow *aMsgWindow, PRBool aForceToServer, PRBool aGetOnlyNew)
+nsNntpIncomingServer::StartPopulating(nsIMsgWindow *aMsgWindow, bool aForceToServer, bool aGetOnlyNew)
 {
   nsresult rv;
 
@@ -965,13 +970,13 @@ nsNntpIncomingServer::StartPopulating(nsIMsgWindow *aMsgWindow, PRBool aForceToS
   rv = SetDelimiter(NEWS_DELIMITER);
   if (NS_FAILED(rv)) return rv;
 
-  rv = SetShowFullName(PR_TRUE);
+  rv = SetShowFullName(true);
   if (NS_FAILED(rv)) return rv;
 
   nsCOMPtr<nsINntpService> nntpService = do_GetService(NS_NNTPSERVICE_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv,rv);
 
-  mHostInfoLoaded = PR_FALSE;
+  mHostInfoLoaded = false;
   mVersion = INVALID_VERSION;
   mGroupsOnServer.Clear();
   mGetOnlyNew = aGetOnlyNew;
@@ -985,7 +990,7 @@ nsNntpIncomingServer::StartPopulating(nsIMsgWindow *aMsgWindow, PRBool aForceToS
   if (aForceToServer || !mHostInfoLoaded || (mVersion != VALID_VERSION)) {
     // set these to true, so when we are done and we call WriteHostInfoFile()
     // we'll write out to hostinfo.dat
-  mHostInfoHasChanged = PR_TRUE;
+  mHostInfoHasChanged = true;
   mVersion = VALID_VERSION;
 
   mGroupsOnServer.Clear();
@@ -1027,7 +1032,7 @@ nsNntpIncomingServer::AddNewsgroupToList(const char *aName)
     }
 
     rv = AddTo(NS_ConvertUTF16toUTF8(newsgroupName),
-               PR_FALSE, PR_TRUE, PR_TRUE);
+               false, true, true);
     if (NS_FAILED(rv)) return rv;
     return NS_OK;
 }
@@ -1041,7 +1046,7 @@ nsNntpIncomingServer::SetIncomingServer(nsIMsgIncomingServer *aServer)
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::SetShowFullName(PRBool showFullName)
+nsNntpIncomingServer::SetShowFullName(bool showFullName)
 {
     nsresult rv = EnsureInner();
     NS_ENSURE_SUCCESS(rv,rv);
@@ -1101,8 +1106,8 @@ nsNntpIncomingServer::SetDelimiter(char aDelimiter)
 NS_IMETHODIMP
 nsNntpIncomingServer::SetAsSubscribed(const nsACString &path)
 {
-    mTempSubscribed.AppendCString(path);
-    if (mGetOnlyNew && (mGroupsOnServer.IndexOf(path) == -1))
+    mTempSubscribed.AppendElement(path);
+    if (mGetOnlyNew && (mGroupsOnServer.IndexOf(path) == mGroupsOnServer.NoIndex))
       return NS_OK;
 
     nsresult rv = EnsureInner();
@@ -1110,35 +1115,21 @@ nsNntpIncomingServer::SetAsSubscribed(const nsACString &path)
     return mInner->SetAsSubscribed(path);
 }
 
-PRBool
-setAsSubscribedFunction(nsCString &aElement, void *aData)
-{
-    nsresult rv = NS_OK;
-    nsNntpIncomingServer *server;
-    server = (nsNntpIncomingServer *)aData;
-    NS_ASSERTION(server, "no server");
-    if (!server) {
-        return PR_FALSE;
-    }
-
-    rv = server->SetAsSubscribed(aElement);
-    NS_ASSERTION(NS_SUCCEEDED(rv),"SetAsSubscribed failed");
-    return PR_TRUE;
-}
-
 NS_IMETHODIMP
 nsNntpIncomingServer::UpdateSubscribed()
 {
-    nsresult rv = EnsureInner();
-    NS_ENSURE_SUCCESS(rv,rv);
+  nsresult rv = EnsureInner();
+  NS_ENSURE_SUCCESS(rv,rv);
   mTempSubscribed.Clear();
-  mSubscribedNewsgroups.EnumerateForwards((nsCStringArrayEnumFunc)setAsSubscribedFunction, (void *)this);
+  PRUint32 length = mSubscribedNewsgroups.Length();
+  for (PRUint32 i = 0; i < length; ++i)
+    SetAsSubscribed(mSubscribedNewsgroups[i]);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::AddTo(const nsACString &aName, PRBool addAsSubscribed,
-                            PRBool aSubscribable, PRBool changeIfExists)
+nsNntpIncomingServer::AddTo(const nsACString &aName, bool addAsSubscribed,
+                            bool aSubscribable, bool changeIfExists)
 {
     NS_ASSERTION(MsgIsUTF8(aName), "Non-UTF-8 newsgroup name");
     nsresult rv = EnsureInner();
@@ -1237,12 +1228,12 @@ nsNntpIncomingServer::Unsubscribe(const PRUnichar *aUnicharName)
   if (!newsgroupFolder)
     return NS_ERROR_FAILURE;
 
-  rv = serverFolder->PropagateDelete(newsgroupFolder, PR_TRUE /* delete storage */, nsnull);
+  rv = serverFolder->PropagateDelete(newsgroupFolder, true /* delete storage */, nsnull);
   if (NS_FAILED(rv))
     return rv;
 
   // since we've unsubscribed to a newsgroup, the newsrc needs to be written out
-  rv = SetNewsrcHasChanged(PR_TRUE);
+  rv = SetNewsrcHasChanged(true);
   if (NS_FAILED(rv))
     return rv;
 
@@ -1269,17 +1260,17 @@ nsNntpIncomingServer::HandleLine(const char* line, PRUint32 line_size)
 #ifdef DEBUG_jungshik
     NS_ASSERTION(MsgIsUTF8(nsDependentCString(line)), "newsrc line is not utf-8");
 #endif
-    nsresult rv = AddTo(nsDependentCString(line), PR_FALSE, PR_TRUE, PR_TRUE);
+    nsresult rv = AddTo(nsDependentCString(line), false, true, true);
     NS_ASSERTION(NS_SUCCEEDED(rv),"failed to add line");
     if (NS_SUCCEEDED(rv)) {
       // since we've seen one group, we can claim we've loaded the
       // hostinfo file
-      mHostInfoLoaded = PR_TRUE;
+      mHostInfoLoaded = true;
     }
   }
   else {
     if (PL_strncmp(line,"begingroups", 11) == 0) {
-      mHasSeenBeginGroups = PR_TRUE;
+      mHasSeenBeginGroups = true;
     }
     char*equalPos = (char *) PL_strchr(line, '=');
     if (equalPos) {
@@ -1303,7 +1294,7 @@ nsNntpIncomingServer::HandleLine(const char* line, PRUint32 line_size)
 nsresult
 nsNntpIncomingServer::AddGroupOnServer(const nsACString &aName)
 {
-  mGroupsOnServer.AppendCString(aName);
+  mGroupsOnServer.AppendElement(aName);
   return NS_OK;
 }
 
@@ -1311,7 +1302,7 @@ NS_IMETHODIMP
 nsNntpIncomingServer::AddNewsgroup(const nsAString &aName)
 {
     // handle duplicates?
-    mSubscribedNewsgroups.AppendCString(NS_ConvertUTF16toUTF8(aName));
+    mSubscribedNewsgroups.AppendElement(NS_ConvertUTF16toUTF8(aName));
     return NS_OK;
 }
 
@@ -1319,13 +1310,13 @@ NS_IMETHODIMP
 nsNntpIncomingServer::RemoveNewsgroup(const nsAString &aName)
 {
     // handle duplicates?
-    mSubscribedNewsgroups.RemoveCString(NS_ConvertUTF16toUTF8(aName));
+    mSubscribedNewsgroups.RemoveElement(NS_ConvertUTF16toUTF8(aName));
     return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::SetState(const nsACString &path, PRBool state,
-                               PRBool *stateChanged)
+nsNntpIncomingServer::SetState(const nsACString &path, bool state,
+                               bool *stateChanged)
 {
     nsresult rv = EnsureInner();
     NS_ENSURE_SUCCESS(rv,rv);
@@ -1333,15 +1324,15 @@ nsNntpIncomingServer::SetState(const nsACString &path, PRBool state,
     rv = mInner->SetState(path, state, stateChanged);
     if (*stateChanged) {
       if (state)
-        mTempSubscribed.AppendCString(path);
+        mTempSubscribed.AppendElement(path);
       else
-        mTempSubscribed.RemoveCString(path);
+        mTempSubscribed.RemoveElement(path);
     }
     return rv;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::HasChildren(const nsACString &path, PRBool *aHasChildren)
+nsNntpIncomingServer::HasChildren(const nsACString &path, bool *aHasChildren)
 {
     nsresult rv = EnsureInner();
     NS_ENSURE_SUCCESS(rv,rv);
@@ -1350,7 +1341,7 @@ nsNntpIncomingServer::HasChildren(const nsACString &path, PRBool *aHasChildren)
 
 NS_IMETHODIMP
 nsNntpIncomingServer::IsSubscribed(const nsACString &path,
-                                   PRBool *aIsSubscribed)
+                                   bool *aIsSubscribed)
 {
     nsresult rv = EnsureInner();
     NS_ENSURE_SUCCESS(rv,rv);
@@ -1359,7 +1350,7 @@ nsNntpIncomingServer::IsSubscribed(const nsACString &path,
 
 NS_IMETHODIMP
 nsNntpIncomingServer::IsSubscribable(const nsACString &path,
-                                     PRBool *aIsSubscribable)
+                                     bool *aIsSubscribable)
 {
     nsresult rv = EnsureInner();
     NS_ENSURE_SUCCESS(rv,rv);
@@ -1398,7 +1389,7 @@ nsNntpIncomingServer::CommitSubscribeChanges()
 
     // we force the newrc to be dirty, so it will get written out when
     // we call WriteNewsrcFile()
-    rv = SetNewsrcHasChanged(PR_TRUE);
+    rv = SetNewsrcHasChanged(true);
     NS_ENSURE_SUCCESS(rv,rv);
     return WriteNewsrcFile();
 }
@@ -1418,9 +1409,7 @@ nsNntpIncomingServer::ForgetPassword()
     NS_ENSURE_SUCCESS(rv,rv);
     if (!newsFolder) return NS_ERROR_FAILURE;
 
-    rv = newsFolder->ForgetGroupUsername();
-    NS_ENSURE_SUCCESS(rv,rv);
-    rv = newsFolder->ForgetGroupPassword();
+    rv = newsFolder->ForgetAuthenticationCredentials();
     NS_ENSURE_SUCCESS(rv,rv);
 
     // clear password of all child folders
@@ -1429,7 +1418,7 @@ nsNntpIncomingServer::ForgetPassword()
     rv = rootFolder->GetSubFolders(getter_AddRefs(subFolders));
     NS_ENSURE_SUCCESS(rv,rv);
 
-    PRBool moreFolders = PR_FALSE;
+    bool moreFolders = false;
 
     nsresult return_rv = NS_OK;
 
@@ -1440,9 +1429,7 @@ nsNntpIncomingServer::ForgetPassword()
         if (NS_SUCCEEDED(rv) && child) {
             newsFolder = do_QueryInterface(child, &rv);
             if (NS_SUCCEEDED(rv) && newsFolder) {
-                rv = newsFolder->ForgetGroupUsername();
-                if (NS_FAILED(rv)) return_rv = rv;
-                rv = newsFolder->ForgetGroupPassword();
+                rv = newsFolder->ForgetAuthenticationCredentials();
                 if (NS_FAILED(rv)) return_rv = rv;
             }
             else {
@@ -1455,13 +1442,13 @@ nsNntpIncomingServer::ForgetPassword()
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetSupportsExtensions(PRBool *aSupportsExtensions)
+nsNntpIncomingServer::GetSupportsExtensions(bool *aSupportsExtensions)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::SetSupportsExtensions(PRBool aSupportsExtensions)
+nsNntpIncomingServer::SetSupportsExtensions(bool aSupportsExtensions)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1473,24 +1460,24 @@ nsNntpIncomingServer::AddExtension(const char *extension)
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::QueryExtension(const char *extension, PRBool *result)
+nsNntpIncomingServer::QueryExtension(const char *extension, bool *result)
 {
 #ifdef DEBUG_seth
   printf("no extension support yet\n");
 #endif
-  *result = PR_FALSE;
+  *result = false;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetPostingAllowed(PRBool *aPostingAllowed)
+nsNntpIncomingServer::GetPostingAllowed(bool *aPostingAllowed)
 {
   *aPostingAllowed = mPostingAllowed;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::SetPostingAllowed(PRBool aPostingAllowed)
+nsNntpIncomingServer::SetPostingAllowed(bool aPostingAllowed)
 {
   mPostingAllowed = aPostingAllowed;
   return NS_OK;
@@ -1528,7 +1515,7 @@ nsNntpIncomingServer::AddSearchableGroup(const nsAString &name)
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::QuerySearchableGroup(const nsAString &name, PRBool *result)
+nsNntpIncomingServer::QuerySearchableGroup(const nsAString &name, bool *result)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1540,7 +1527,7 @@ nsNntpIncomingServer::AddSearchableHeader(const char *name)
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::QuerySearchableHeader(const char *name, PRBool *result)
+nsNntpIncomingServer::QuerySearchableHeader(const char *name, bool *result)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1581,7 +1568,7 @@ nsNntpIncomingServer::GetFirstGroupNeedingExtraInfo(nsACString &result)
 
 NS_IMETHODIMP
 nsNntpIncomingServer::SetGroupNeedsExtraInfo(const nsACString &name,
-                                             PRBool needsExtraInfo)
+                                             bool needsExtraInfo)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1589,7 +1576,7 @@ nsNntpIncomingServer::SetGroupNeedsExtraInfo(const nsACString &name,
 
 NS_IMETHODIMP
 nsNntpIncomingServer::GroupNotFound(nsIMsgWindow *aMsgWindow,
-                                    const nsAString &aName, PRBool aOpening)
+                                    const nsAString &aName, bool aOpening)
 {
   nsresult rv;
   nsCOMPtr <nsIPrompt> prompt;
@@ -1605,8 +1592,9 @@ nsNntpIncomingServer::GroupNotFound(nsIMsgWindow *aMsgWindow,
     NS_ENSURE_SUCCESS(rv,rv);
   }
 
-  nsCOMPtr <nsIStringBundleService> bundleService = do_GetService(NS_STRINGBUNDLE_CONTRACTID,&rv);
-  NS_ENSURE_SUCCESS(rv,rv);
+  nsCOMPtr <nsIStringBundleService> bundleService =
+    mozilla::services::GetStringBundleService();
+  NS_ENSURE_TRUE(bundleService, NS_ERROR_UNEXPECTED);
 
   nsCOMPtr <nsIStringBundle> bundle;
   rv = bundleService->CreateBundle(NEWS_MSGS_URL, getter_AddRefs(bundle));
@@ -1627,7 +1615,7 @@ nsNntpIncomingServer::GroupNotFound(nsIMsgWindow *aMsgWindow,
                     getter_Copies(confirmText));
   NS_ENSURE_SUCCESS(rv,rv);
 
-  PRBool confirmResult = PR_FALSE;
+  bool confirmResult = false;
   rv = prompt->Confirm(nsnull, confirmText.get(), &confirmResult);
   NS_ENSURE_SUCCESS(rv,rv);
 
@@ -1647,10 +1635,10 @@ nsNntpIncomingServer::SetPrettyNameForGroup(const nsAString &name,
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetCanSearchMessages(PRBool *canSearchMessages)
+nsNntpIncomingServer::GetCanSearchMessages(bool *canSearchMessages)
 {
     NS_ENSURE_ARG_POINTER(canSearchMessages);
-    *canSearchMessages = PR_TRUE;
+    *canSearchMessages = true;
     return NS_OK;
 }
 
@@ -1669,7 +1657,7 @@ nsNntpIncomingServer::GetOfflineSupportLevel(PRInt32 *aSupportLevel)
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetDefaultCopiesAndFoldersPrefsToServer(PRBool *aCopiesAndFoldersOnServer)
+nsNntpIncomingServer::GetDefaultCopiesAndFoldersPrefsToServer(bool *aCopiesAndFoldersOnServer)
 {
     NS_ENSURE_ARG_POINTER(aCopiesAndFoldersOnServer);
 
@@ -1680,79 +1668,61 @@ nsNntpIncomingServer::GetDefaultCopiesAndFoldersPrefsToServer(PRBool *aCopiesAnd
      * They'll point to the ones on "Local Folders"
      */
 
-    *aCopiesAndFoldersOnServer = PR_FALSE;
+    *aCopiesAndFoldersOnServer = false;
     return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetCanCreateFoldersOnServer(PRBool *aCanCreateFoldersOnServer)
+nsNntpIncomingServer::GetCanCreateFoldersOnServer(bool *aCanCreateFoldersOnServer)
 {
     NS_ENSURE_ARG_POINTER(aCanCreateFoldersOnServer);
 
     // No folder creation on news servers. Return false.
-    *aCanCreateFoldersOnServer = PR_FALSE;
+    *aCanCreateFoldersOnServer = false;
     return NS_OK;
 }
 
-PRBool
-buildSubscribeSearchResult(nsCString &aElement, void *aData)
-{
-    nsresult rv = NS_OK;
-    nsNntpIncomingServer *server;
-    server = (nsNntpIncomingServer *)aData;
-    NS_ASSERTION(server, "no server");
-    if (!server) {
-        return PR_FALSE;
-    }
-
-    rv = server->AppendIfSearchMatch(aElement);
-    NS_ASSERTION(NS_SUCCEEDED(rv),"AddSubscribeSearchResult failed");
-    return PR_TRUE;
-}
-
-nsresult
-nsNntpIncomingServer::AppendIfSearchMatch(nsCString& newsgroupName)
-{
-  NS_ConvertUTF8toUTF16 groupName(newsgroupName);
-  if (CaseInsensitiveFindInReadable(mSearchValue, groupName))
-      mSubscribeSearchResult.AppendCString(newsgroupName);
-  return NS_OK;
-}
-
 NS_IMETHODIMP
 nsNntpIncomingServer::SetSearchValue(const nsAString &searchValue)
 {
-    mSearchValue = searchValue;
+  mSearchValue = searchValue;
 
-    if (mTree) {
-        mTree->BeginUpdateBatch();
-        mTree->RowCountChanged(0, -mSubscribeSearchResult.Count());
-    }
+  if (mTree) {
+    mTree->BeginUpdateBatch();
+    mTree->RowCountChanged(0, -mSubscribeSearchResult.Length());
+  }
 
-    mSubscribeSearchResult.Clear();
-    mGroupsOnServer.
-        EnumerateForwards(nsCStringArrayEnumFunc(buildSubscribeSearchResult),
-                          (void *)this);
-    mSubscribeSearchResult.SortIgnoreCase();
+  mSubscribeSearchResult.Clear();
+  PRUint32 length = mGroupsOnServer.Length();
+  for (PRUint32 i = 0; i < length; i++)
+  {
+    if (CaseInsensitiveFindInReadable(mSearchValue, NS_ConvertUTF8toUTF16(mGroupsOnServer[i])))
+      mSubscribeSearchResult.AppendElement(mGroupsOnServer[i]);
+  }
 
-    if (mTree) {
-        mTree->RowCountChanged(0, mSubscribeSearchResult.Count());
-        mTree->EndUpdateBatch();
-    }
-    return NS_OK;
+  nsCStringLowerCaseComparator comparator;
+  mSubscribeSearchResult.Sort(comparator);
+
+  if (mTree)
+  {
+    mTree->RowCountChanged(0, mSubscribeSearchResult.Length());
+    mTree->EndUpdateBatch();
+  }
+
+  return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetSupportsSubscribeSearch(PRBool *retVal)
+nsNntpIncomingServer::GetSupportsSubscribeSearch(bool *retVal)
 {
-    *retVal = PR_TRUE;
+    *retVal = true;
     return NS_OK;
 }
 
 NS_IMETHODIMP
 nsNntpIncomingServer::GetRowCount(PRInt32 *aRowCount)
 {
-    *aRowCount = mSubscribeSearchResult.Count();
+    *aRowCount = mSubscribeSearchResult.Length();
     return NS_OK;
 }
 
@@ -1792,11 +1762,9 @@ nsNntpIncomingServer::GetCellProperties(PRInt32 row, nsITreeColumn* col, nsISupp
         // if <name> is in our temporary list of subscribed groups
         // add the "subscribed" property so the check mark shows up
         // in the "subscribedCol"
-        nsCString name;
         if (mSearchResultSortDescending)
-          row = mSubscribeSearchResult.Count() + ~row;
-        mSubscribeSearchResult.CStringAt(row, name);
-        if (mTempSubscribed.IndexOf(name) != -1) {
+          row = mSubscribeSearchResult.Length() - 1 - row;
+        if (mTempSubscribed.IndexOf(mSubscribeSearchResult.ElementAt(row)) != mTempSubscribed.NoIndex) {
           properties->AppendElement(mSubscribedAtom);
         }
     }
@@ -1815,33 +1783,33 @@ nsNntpIncomingServer::GetColumnProperties(nsITreeColumn* col, nsISupportsArray *
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::IsContainer(PRInt32 index, PRBool *_retval)
+nsNntpIncomingServer::IsContainer(PRInt32 index, bool *_retval)
 {
-    *_retval = PR_FALSE;
+    *_retval = false;
     return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::IsContainerOpen(PRInt32 index, PRBool *_retval)
+nsNntpIncomingServer::IsContainerOpen(PRInt32 index, bool *_retval)
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::IsContainerEmpty(PRInt32 index, PRBool *_retval)
+nsNntpIncomingServer::IsContainerEmpty(PRInt32 index, bool *_retval)
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::IsSeparator(PRInt32 index, PRBool *_retval)
+nsNntpIncomingServer::IsSeparator(PRInt32 index, bool *_retval)
 {
-    *_retval = PR_FALSE;
+    *_retval = false;
     return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::IsSorted(PRBool *_retval)
+nsNntpIncomingServer::IsSorted(bool *_retval)
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1850,7 +1818,7 @@ NS_IMETHODIMP
 nsNntpIncomingServer::CanDrop(PRInt32 index,
                               PRInt32 orientation,
                               nsIDOMDataTransfer *dataTransfer,
-                              PRBool *_retval)
+                              bool *_retval)
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1870,7 +1838,7 @@ nsNntpIncomingServer::GetParentIndex(PRInt32 rowIndex, PRInt32 *_retval)
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::HasNextSibling(PRInt32 rowIndex, PRInt32 afterIndex, PRBool *_retval)
+nsNntpIncomingServer::HasNextSibling(PRInt32 rowIndex, PRInt32 afterIndex, bool *_retval)
 {
     return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1885,7 +1853,7 @@ nsNntpIncomingServer::GetLevel(PRInt32 index, PRInt32 *_retval)
 nsresult
 nsNntpIncomingServer::IsValidRow(PRInt32 row)
 {
-    return ((row >= 0) && (row < mSubscribeSearchResult.Count()));
+  return ((row >= 0) && (row < (PRInt32)mSubscribeSearchResult.Length()));
 }
 
 NS_IMETHODIMP
@@ -1921,11 +1889,10 @@ nsNntpIncomingServer::GetCellText(PRInt32 row, nsITreeColumn* col, nsAString& _r
     if (colID[0] == 'n') {
       nsCAutoString str;
       if (mSearchResultSortDescending)
-        row = mSubscribeSearchResult.Count() + ~row;
-      mSubscribeSearchResult.CStringAt(row, str);
+        row = mSubscribeSearchResult.Length() - 1 - row;
       // some servers have newsgroup names that are non ASCII.  we store
       // those as escaped. unescape here so the UI is consistent
-      rv = NS_MsgDecodeUnescapeURLPath(str, _retval);
+      rv = NS_MsgDecodeUnescapeURLPath(mSubscribeSearchResult.ElementAt(row), _retval);
     }
     return rv;
 }
@@ -1969,7 +1936,7 @@ nsNntpIncomingServer::CycleHeader(nsITreeColumn* col)
 {
     NS_ENSURE_ARG_POINTER(col);
 
-    PRBool cycler;
+    bool cycler;
     col->GetCycler(&cycler);
     if (!cycler) {
         NS_NAMED_LITERAL_STRING(dir, "sortDirection");
@@ -1996,16 +1963,16 @@ nsNntpIncomingServer::CycleCell(PRInt32 row, nsITreeColumn* col)
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::IsEditable(PRInt32 row, nsITreeColumn* col, PRBool *_retval)
+nsNntpIncomingServer::IsEditable(PRInt32 row, nsITreeColumn* col, bool *_retval)
 {
-    *_retval = PR_FALSE;
+    *_retval = false;
     return NS_OK;
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::IsSelectable(PRInt32 row, nsITreeColumn* col, PRBool *_retval)
+nsNntpIncomingServer::IsSelectable(PRInt32 row, nsITreeColumn* col, bool *_retval)
 {
-    *_retval = PR_FALSE;
+    *_retval = false;
     return NS_OK;
 }
 
@@ -2040,12 +2007,12 @@ nsNntpIncomingServer::PerformActionOnCell(const PRUnichar *action, PRInt32 row,
 }
 
 NS_IMETHODIMP
-nsNntpIncomingServer::GetCanFileMessagesOnServer(PRBool *aCanFileMessagesOnServer)
+nsNntpIncomingServer::GetCanFileMessagesOnServer(bool *aCanFileMessagesOnServer)
 {
     NS_ENSURE_ARG_POINTER(aCanFileMessagesOnServer);
 
     // No folder creation on news servers. Return false.
-    *aCanFileMessagesOnServer = PR_FALSE;
+    *aCanFileMessagesOnServer = false;
     return NS_OK;
 }
 
@@ -2099,7 +2066,7 @@ nsNntpIncomingServer::GetSocketType(PRInt32 *aSocketType)
   // doesn't mix. Migrate if that's the case here.
   if (*aSocketType == nsMsgSocketType::plain)
   {
-    PRBool isSecure = PR_FALSE;
+    bool isSecure = false;
     nsresult rv2 = mPrefBranch->GetBoolPref("isSecure", &isSecure);
     if (NS_SUCCEEDED(rv2) && isSecure)
     {
@@ -2119,7 +2086,7 @@ nsNntpIncomingServer::SetSocketType(PRInt32 aSocketType)
   nsresult rv = nsMsgIncomingServer::SetSocketType(aSocketType);
   if (NS_SUCCEEDED(rv))
   {
-    PRBool isSecure = PR_FALSE;
+    bool isSecure = false;
     if (NS_SUCCEEDED(mPrefBranch->GetBoolPref("isSecure", &isSecure)))
     {
       // Must keep isSecure in sync since we migrate based on it... if it's set.
@@ -2146,7 +2113,7 @@ nsNntpIncomingServer::OnUserOrHostNameChanged(const nsACString& oldName, const n
   NS_ENSURE_SUCCESS(rv, rv);
   rv = hostInfoFile->AppendNative(NS_LITERAL_CSTRING(HOSTINFO_FILE_NAME));
   NS_ENSURE_SUCCESS(rv, rv);
-  hostInfoFile->Remove(PR_FALSE);
+  hostInfoFile->Remove(false);
 
   // 3.Unsubscribe and then subscribe the existing groups to clean up the article numbers
   //   in the rc file (this is because the old and new servers may maintain different
@@ -2163,7 +2130,7 @@ nsNntpIncomingServer::OnUserOrHostNameChanged(const nsACString& oldName, const n
   nsString folderName;
 
   // Prepare the group list
-  PRBool hasMore;
+  bool hasMore;
   while (NS_SUCCEEDED(subFolders->HasMoreElements(&hasMore)) && hasMore)
   {
     nsCOMPtr<nsISupports> item;
